@@ -66,11 +66,36 @@ mvNcdf <-  function(l, u, Sig, n = 1e5){
                                 control = list(maxit = 500L))
     xmu <- solvneq$x
     exitflag <- solvneq$termcd
+    flag <- TRUE
     if(!(exitflag %in% 1:2) || !isTRUE(all.equal(solvneq$fvec, rep(0, length(x0)), tolerance = 1e-6))){
-      warning('Did not find a solution to the nonlinear system in `mvrandn`!')
+      flag <- FALSE
     }
     x <- xmu[1:(d-1)]
     mu <- xmu[d:(2*d-2)] # assign saddlepoint x* and mu*
+    if(any((out$L %*% c(x,0) - out$u)[-d] > 0, (-out$L %*% c(x,0) + out$l)[-d] > 0)){
+      warning("Solution to exponential tilting problem using Powell's dogleg method \n  does not lie in convex set l < Lx < u.")
+      flag <- FALSE
+    }
+    # If Powell dogleg method fails, try constrained convex solver
+    if(!flag){
+      solvneqc <- alabama::auglag(par = xmu,
+                                  fn = function(par, l=l, L=L, u=u){
+                                    ps <- try(-psy(x = c(par[1:(d-1)],0), mu = c(par[d:(2*d-2)],0),
+                                                   l = l, L = L, u = u))
+                                    return(ifelse(is.character(ps), -1e10, ps))},
+                                  gr = function(x, l=l, L=L, u=u){gradpsi(y=x, L=L,l=l, u=u)},
+                                  L=L, l=l, u=u,
+                                  # equality constraints d psi/d mu = 0
+                                  heq = function(x, l, L, u){gradpsi(y = x, l=l, L=L, u = u)[d:(2*d-2)]},
+                                  hin= function(par,...){c((out$u - out$L %*% c(par[1:(d-1)],0))[-d] > 0, (out$L %*% c(par[1:(d-1)],0) - out$l)[-d])},
+                                  control.outer = list(trace = FALSE,method="nlminb"))
+      if(solvneqc$convergence == 0){
+        x <- solvneqc$par[1:(d-1)]
+        mu <- solvneqc$par[d:(2*d-2)] 
+      } else{
+        stop('Did not find a solution to the nonlinear system in `mvNqmc`!') 
+      }
+    }
     est <- mvnpr(n, L, l, u, mu)
     # compute psi star
     est$upbnd <- exp(psy(x, L, l, u, mu))
