@@ -5,18 +5,20 @@ tn <-
     # truncated over the region [l,u], where -a<l<u<a for some
     # 'a' and l and u are column vectors;
     # uses acceptance rejection and inverse-transform method;
-    tol=2.05 # controls switch between methods
+    tol <- 2.05 # controls switch between methods
     # threshold can be tuned for maximum speed for each platform
     # case: abs(u-l)>tol, uses accept-reject from randn
-    x=l;I=(abs(u-l)>tol)
+    x <- rep(0, length(l));
+    I <- (abs(u-l)>tol)
     if (any(I)){
-      tl=l[I];tu=u[I];x[I]=trnd(tl,tu)
+      x[I] <- trnd(l[I], u[I])
     }
-    # case: abs(u-l)<tol, uses inverse-transform
-    I<-!I
+    # case: abs(u-l)< tol, uses inverse-transform
+    I <- !I
     if (any(I)){
-      tl=l[I];tu=u[I];pl=pnorm(tl);pu=pnorm(tu);
-      x[I]=qnorm(pl+(pu-pl)*runif(length(tl)))
+      pl <- pnorm(l[I])
+      pu <- pnorm(u[I]);
+      x[I] <- qnorm(pl+(pu-pl)*runif(length(pl)))
     }
     return(x)
   }
